summaryrefslogtreecommitdiff
path: root/ext/pgsql
diff options
context:
space:
mode:
authorYasuo Ohgaki <yohgaki@php.net>2002-01-21 00:36:22 +0000
committerYasuo Ohgaki <yohgaki@php.net>2002-01-21 00:36:22 +0000
commitae64c5cec315d557f79853dd47c62e109bc3d6e6 (patch)
tree9ebb7fde2446b90936ec531593749357b2e871c4 /ext/pgsql
parent1769e3fcdc1c0338cbd0c422e04fbea62e541e48 (diff)
downloadphp-git-ae64c5cec315d557f79853dd47c62e109bc3d6e6.tar.gz
Fixed typo and proto
Diffstat (limited to 'ext/pgsql')
-rw-r--r--ext/pgsql/pgsql.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/ext/pgsql/pgsql.c b/ext/pgsql/pgsql.c
index a0f2200e23..30dceb3f2c 100644
--- a/ext/pgsql/pgsql.c
+++ b/ext/pgsql/pgsql.c
@@ -340,7 +340,7 @@ PHP_MINIT_FUNCTION(pgsql)
REGISTER_LONG_CONSTANT("PGSQL_ESCAPE_BYTEA", PGSQL_ESCAPE_BYTEA, CONST_CS | CONST_PERSISTENT);
REGISTER_LONG_CONSTANT("PGSQL_EMPTY_QUERY", PGRES_EMPTY_QUERY, CONST_CS | CONST_PERSISTENT);
- REGISTER_LONG_CONSTANT("PSQL_COMMAND_OK", PGRES_COMMAND_OK, CONST_CS | CONST_PERSISTENT);
+ REGISTER_LONG_CONSTANT("PGSQL_COMMAND_OK", PGRES_COMMAND_OK, CONST_CS | CONST_PERSISTENT);
REGISTER_LONG_CONSTANT("PGSQL_TUPLES_OK", PGRES_TUPLES_OK, CONST_CS | CONST_PERSISTENT);
REGISTER_LONG_CONSTANT("PGSQL_COPY_OUT", PGRES_COPY_OUT, CONST_CS | CONST_PERSISTENT);
REGISTER_LONG_CONSTANT("PGSQL_COPY_IN", PGRES_COPY_IN, CONST_CS | CONST_PERSISTENT);
@@ -2103,8 +2103,8 @@ PHP_FUNCTION(pg_put_line)
}
/* }}} */
-/* {{{ proto int pg_copy_to(int connection, string table_name [, string delimiter [, string null_as]])
- Send null-terminated string to backend server*/
+/* {{{ proto array pg_copy_to(int connection, string table_name [, string delimiter [, string null_as]])
+ Copy table to array */
PHP_FUNCTION(pg_copy_to)
{
zval *pgsql_link;
@@ -2221,8 +2221,8 @@ PHP_FUNCTION(pg_copy_to)
}
/* }}} */
-/* {{{ proto int pg_copy_from(int connection, string table_name , array rows [, string delimiter [, string null_as]])
- */
+/* {{{ proto bool pg_copy_from(int connection, string table_name , array rows [, string delimiter [, string null_as]])
+ Copy table from array */
PHP_FUNCTION(pg_copy_from)
{
zval *pgsql_link = NULL, *pg_rows;